NAME
Mail::Message::Field::Unstructured - smart unstructured field
INHERITANCE
Mail::Message::Field::Unstructured
is a Mail::Message::Field::Full
is a Mail::Message::Field
is a Mail::Reporter
SYNOPSIS
my $f = Mail::Message::Field::Unstructured->new(Comments => 'hi!');
DESCRIPTION
Unstructured fields do contain information which is not restricted in any way. RFC2822 defines some unstructured fields, but by default all unknown fields are unstructured as well. Things like attributes and comments have no meaning for unstructured fields, but encoding does.
OVERLOADED
overload: ""
See "OVERLOADED" in Mail::Message::Field
overload: +0
See "OVERLOADED" in Mail::Message::Field
overload: <=>
See "OVERLOADED" in Mail::Message::Field
overload: bool
See "OVERLOADED" in Mail::Message::Field
overload: cmp
See "OVERLOADED" in Mail::Message::Field
overload: stringification
See "OVERLOADED" in Mail::Message::Field::Full
METHODS
Constructors
$obj->clone
See "Constructors" in Mail::Message::Field
Mail::Message::Field::Unstructured->from(FIELD, OPTIONS)
See "Constructors" in Mail::Message::Field::Full
Mail::Message::Field::Unstructured->new(DATA)
When the DATA is specified as single line, the content part is considered to be correcly (character) encoded and escaped. Typically, it is a line as read from file. The folding of the line is kept as is.
In case more than one argument is provided, the second is considered the BODY. Attributes and other special things are not defined for unstructured fields, and therefore not valid options. The BODY can be a single string, a single OBJECT, or an array of OBJECTS. The objects are stringified (into a comma separated list). Each BODY element is interpreted with the specified encoding.
When the BODY is empty, the construction of the object fails: undef is returned.
Option Defined in Default
charset L<Mail::Message::Field::Full> undef
encoding L<Mail::Message::Field::Full> C<'q'>
force L<Mail::Message::Field::Full> false
language L<Mail::Message::Field::Full> undef
log L<Mail::Reporter> C<'WARNINGS'>
trace L<Mail::Reporter> C<'WARNINGS'>
. charset STRING
. encoding 'q'|'Q'|'b'|'B'
. force BOOLEAN
. language STRING
. log LEVEL
. trace LEVEL
Example:
my $s = Mail::Message::Field::Unstructured->new('Comment', 'Hi!');
# Use autodetect
my $s = Mail::Message::Field::Full->new('Comment', 'Hi!');
my $s = Mail::Message::Field::Full->new('Comment: Hi!');
The field
$obj->isStructured
Mail::Message::Field::Unstructured->isStructured
See "The field" in Mail::Message::Field
$obj->length
See "The field" in Mail::Message::Field
$obj->nrLines
See "The field" in Mail::Message::Field
$obj->print([FILEHANDLE])
See "The field" in Mail::Message::Field
$obj->size
See "The field" in Mail::Message::Field
$obj->string([WRAP])
See "The field" in Mail::Message::Field
$obj->toDisclose
See "The field" in Mail::Message::Field
Access to the name
$obj->Name
See "Access to the name" in Mail::Message::Field
$obj->name
See "Access to the name" in Mail::Message::Field
$obj->wellformedName([STRING])
See "Access to the name" in Mail::Message::Field
Access to the body
$obj->body
See "Access to the body" in Mail::Message::Field
$obj->decodedBody(OPTIONS)
See "Access to the body" in Mail::Message::Field::Full
$obj->folded
See "Access to the body" in Mail::Message::Field
$obj->foldedBody([BODY])
See "Access to the body" in Mail::Message::Field
$obj->stripCFWS([STRING])
Mail::Message::Field::Unstructured->stripCFWS([STRING])
See "Access to the body" in Mail::Message::Field
$obj->unfoldedBody([BODY, [WRAP]])
See "Access to the body" in Mail::Message::Field
Access to the content
$obj->addresses
See "Access to the content" in Mail::Message::Field
$obj->attribute(NAME [, VALUE])
See "Access to the content" in Mail::Message::Field
$obj->beautify
See "Access to the content" in Mail::Message::Field::Full
$obj->comment([STRING])
See "Access to the content" in Mail::Message::Field
$obj->createComment(STRING, OPTIONS)
Mail::Message::Field::Unstructured->createComment(STRING, OPTIONS)
See "Access to the content" in Mail::Message::Field::Full
$obj->createPhrase(STRING, OPTIONS)
Mail::Message::Field::Unstructured->createPhrase(STRING, OPTIONS)
See "Access to the content" in Mail::Message::Field::Full
$obj->study
See "Access to the content" in Mail::Message::Field
$obj->toDate([TIME])
Mail::Message::Field::Unstructured->toDate([TIME])
See "Access to the content" in Mail::Message::Field
$obj->toInt
See "Access to the content" in Mail::Message::Field
Other methods
$obj->dateToTimestamp(STRING)
Mail::Message::Field::Unstructured->dateToTimestamp(STRING)
See "Other methods" in Mail::Message::Field
Internals
$obj->consume(LINE | (NAME,BODY|OBJECTS))
See "Internals" in Mail::Message::Field
$obj->decode(STRING, OPTIONS)
Mail::Message::Field::Unstructured->decode(STRING, OPTIONS)
See "Internals" in Mail::Message::Field::Full
$obj->defaultWrapLength([LENGTH])
See "Internals" in Mail::Message::Field
$obj->encode(STRING, OPTIONS)
See "Internals" in Mail::Message::Field::Full
$obj->fold(NAME, BODY, [MAXCHARS])
See "Internals" in Mail::Message::Field
$obj->setWrapLength([LENGTH])
See "Internals" in Mail::Message::Field
$obj->stringifyData(STRING|ARRAY|OBJECTS)
See "Internals" in Mail::Message::Field
$obj->unfold(STRING)
See "Internals" in Mail::Message::Field
Parsing
$obj->consumeComment(STRING)
Mail::Message::Field::Unstructured->consumeComment(STRING)
See "Parsing" in Mail::Message::Field::Full
$obj->consumeDotAtom(STRING)
See "Parsing" in Mail::Message::Field::Full
$obj->consumePhrase(STRING)
Mail::Message::Field::Unstructured->consumePhrase(STRING)
See "Parsing" in Mail::Message::Field::Full
$obj->parse(STRING)
See "Parsing" in Mail::Message::Field::Full
Error handling
$obj->AUTOLOAD
See "Error handling" in Mail::Reporter
$obj->defaultTrace([LEVEL, [LEVEL])
Mail::Message::Field::Unstructured->defaultTrace([LEVEL, [LEVEL])
See "Error handling" in Mail::Reporter
$obj->errors
See "Error handling" in Mail::Reporter
$obj->log([LEVEL [,STRINGS]])
Mail::Message::Field::Unstructured->log([LEVEL [,STRINGS]])
See "Error handling" in Mail::Reporter
$obj->logPriority(LEVEL)
Mail::Message::Field::Unstructured->logPriority(LEVEL)
See "Error handling" in Mail::Reporter
$obj->logSettings
See "Error handling" in Mail::Reporter
$obj->notImplemented
See "Error handling" in Mail::Reporter
$obj->report([LEVEL])
See "Error handling" in Mail::Reporter
$obj->reportAll([LEVEL])
See "Error handling" in Mail::Reporter
$obj->trace([LEVEL])
See "Error handling" in Mail::Reporter
$obj->warnings
See "Error handling" in Mail::Reporter
Cleanup
$obj->DESTROY
See "Cleanup" in Mail::Reporter
$obj->inGlobalDestruction
See "Cleanup" in Mail::Reporter
DIAGNOSTICS
Warning: Field content is not numerical: $content
The numeric value of a field is requested (for instance the Lines or Content-Length fields should be numerical), however the data contains weird characters.
Warning: Illegal character in charset '$charset'
The field is created with an utf8 string which only contains data from the specified character set. However, that character set can never be a valid name because it contains characters which are not permitted.
Warning: Illegal character in field name $name
A new field is being created which does contain characters not permitted by the RFCs. Using this field in messages may break other e-mail clients or transfer agents, and therefore mutulate or extinguish your message.
Warning: Illegal character in language '$lang'
The field is created with data which is specified to be in a certain language, however, the name of the language cannot be valid: it contains characters which are not permitted by the RFCs.
Warning: Illegal encoding '$encoding', used 'q'
The RFCs only permit base64 (b or B ) or quoted-printable (q or Q) encoding. Other than these four options are illegal.
Error: Package $package does not implement $method.
Fatal error: the specific package (or one of its superclasses) does not implement this method where it should. This message means that some other related classes do implement this method however the class at hand does not. Probably you should investigate this and probably inform the author of the package.
DETAILS
REFERENCES
See the MailBox website at http://perl.overmeer.net/mailbox/ for more details.
COPYRIGHTS
Distribution version 2.044. Written by Mark Overmeer (mark@overmeer.net). See the ChangeLog for other contributors.
Copyright (c) 2001-2003 by the author(s). All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.